bayespy.inference.vmp.nodes.node.Moments
========================================

.. currentmodule:: bayespy.inference.vmp.nodes.node

.. autoclass:: Moments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Moments.add_converter
      ~Moments.compute_dims_from_values
      ~Moments.compute_fixed_moments
      ~Moments.get_converter
   
   

   
   
   